import React from "react";
import { HTMLTags, AnimatedProps } from "./common";
export type HoverAnimations = 'hovering' | 'notHovering';
type HoverAnimatedProps<A extends string, T extends HTMLTags = "div"> = {
    /**
     * The optional currentAnimation override that may control this component
     * If present, will override the animation for the current hover state
     * If null or undefined, the component will animate based on the hover state
     * Analogous to currentAnimation in {@link components/ControlledAnimated.ControlledAnimatedProps}
     */
    currentAnimation?: A | null;
} & Omit<AnimatedProps<HoverAnimations | A, T>, "currentAnimation">;
/**
 * An Animated component that will track hover (via mouseenter/mouseleave listeners) and animate based on the corresponding hover state
 * May accept a ref to forward to the HTML tag delegate
 * May accept an overriding currentAnimation
 * @typeParam A additional animation names
 * @typeParam T the HTML Tag delegate
 */
declare const HoverAnimated: <A extends string = never, T extends HTMLTags = "div">(props: HoverAnimatedProps<A, T>) => React.ReactElement<any, any>;
export default HoverAnimated;
