"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
/**
 * Hook to capture the hovering state of a ref'd HTMLElement
 *
 * Note: if the ref is pointed at a new element, isHovered will be the last hoverState of the previous element
 * until a mouseOver/Out event happens on the new element
 *
 * @returns [isHovered, elementRef]
 */
function useIsHovered() {
    const [isHovered, setIsHovered] = (0, react_1.useState)(undefined);
    const ref = (0, react_1.useRef)(null);
    const hovered = (0, react_1.useCallback)(() => setIsHovered(true), []);
    const notHovered = (0, react_1.useCallback)(() => setIsHovered(false), []);
    (0, react_1.useEffect)(() => {
        const el = ref.current;
        if (el) {
            el.addEventListener('mouseover', hovered);
            el.addEventListener('mouseout', notHovered);
            return () => {
                el.removeEventListener('mouseover', hovered);
                el.removeEventListener('mouseout', notHovered);
            };
        }
    }, [ref.current]); // Recall only if ref changes
    return [isHovered, ref];
}
exports.default = useIsHovered;
