"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const useTransitioningState_1 = __importDefault(require("./useTransitioningState"));
/**
 * Hook to useState that supports asynchronous transitions
 *
 * State transitions may be queued via startTransition, and all queued transitions are completed in order by endTransition
 *
 * @typeParam S type of state
 * @param initialState
 * @param initialTransitioning if true, initializes the state with isTransitioning: true
 * @returns [state, startTransition, endTransition, isTransitioning]: SimpleTransitioningState<S>
 */
function useSimpleTransitioningState(initialState, initialTransitioning = false) {
    const [state, startTransition, endTransition, currentTransition] = (0, useTransitioningState_1.default)(initialState, initialTransitioning ? 'transitioning' : null);
    return [
        state,
        (action, shouldTransition = true) => startTransition(action, shouldTransition ? 'transitioning' : null),
        endTransition,
        currentTransition !== null,
    ];
}
exports.default = useSimpleTransitioningState;
